package com.DVInc.TestURCap.impl;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import com.ur.urcap.api.contribution.installation.swing.SwingInstallationNodeView;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardTextInput;

public class TestURCapInstallationNodeView implements SwingInstallationNodeView<TestURCapInstallationNodeContribution>{
	private Style style;
	
	private JTextField	inputText;
	private JTextArea	dataModelContentText;
	
	public TestURCapInstallationNodeView(Style style) {
		this.style = style;
	}

	@Override
	public void buildUI(JPanel panel, TestURCapInstallationNodeContribution contribution) {
		panel.setAlignmentX(Component.LEFT_ALIGNMENT);
		panel.setLayout(new BoxLayout(panel, BoxLayout.Y_AXIS));
		
		panel.add(createInput(contribution));
		panel.add(createVerticalSpacing());
		panel.add(createDataModelCheck());
		
		contribution.setValueDuringInitializing();
	}
	
	private JPanel createInput(final TestURCapInstallationNodeContribution contribution) {
		JPanel inputPanel = new JPanel();
		inputPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		inputPanel.setLayout(new BoxLayout(inputPanel, BoxLayout.Y_AXIS));
		
		JTextArea messageText = new JTextArea();
		messageText.setAlignmentX(Component.LEFT_ALIGNMENT);
		messageText.setBorder(BorderFactory.createEmptyBorder());
		messageText.setBackground(inputPanel.getBackground());
		messageText.setText("Enter something to be stored in dataModel:");
		messageText.setFont(style.getTextFont());
		messageText.setMaximumSize(messageText.getPreferredSize());
		
		inputText = new JTextField();
		inputText.setAlignmentX(Component.LEFT_ALIGNMENT);
		inputText.setPreferredSize(style.getInputFieldSize());
		inputText.setMaximumSize(inputText.getPreferredSize());
		inputText.setText("");
		inputText.addMouseListener(new MouseAdapter() {
			public void mousePressed(MouseEvent e) {
				KeyboardTextInput keyboardInput = contribution.getKeyboardTextInput();
				keyboardInput.show(inputText, contribution.getKeyboardTextInputCallback());
			}
		});
		
		inputPanel.add(messageText);
		inputPanel.add(createVerticalSpacing());
		inputPanel.add(inputText);
		
		return inputPanel;
	}
	
	private JPanel createDataModelCheck() {
		JPanel dataModelContentPanel = new JPanel();
		dataModelContentPanel.setAlignmentX(Component.LEFT_ALIGNMENT);
		dataModelContentPanel.setLayout(new BoxLayout(dataModelContentPanel, BoxLayout.Y_AXIS));
		
		JTextArea messageText = new JTextArea();
		messageText.setAlignmentX(Component.LEFT_ALIGNMENT);
		messageText.setBorder(BorderFactory.createEmptyBorder());
		messageText.setBackground(dataModelContentPanel.getBackground());
		messageText.setText("Value of inputTextField stored in DataModel is:");
		messageText.setFont(style.getTextFont());
		messageText.setMaximumSize(messageText.getPreferredSize());
		
		dataModelContentText = new JTextArea();
		dataModelContentText.setAlignmentX(Component.LEFT_ALIGNMENT);
		dataModelContentText.setBorder(BorderFactory.createEmptyBorder());
		dataModelContentText.setBackground(dataModelContentPanel.getBackground());
		dataModelContentText.setText("");
		dataModelContentText.setFont(style.getTextFont());
		
		dataModelContentPanel.add(messageText);
		dataModelContentPanel.add(createVerticalSpacing());
		dataModelContentPanel.add(dataModelContentText);
		
		return dataModelContentPanel;
	}
	
	public void setInputFieldText(String message) {
		inputText.setText(message);
	}
	
	public void setDataModelContentText(String message) {
		dataModelContentText.setText(message);
	}
	
	private Component createVerticalSpacing() {
		return Box.createRigidArea(new Dimension(0, style.getVerticalSpacing()));
	}
}
